You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@qpid.apache.org by ro...@apache.org on 2009/03/22 22:24:02 UTC

svn commit: r757258 - in /qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue: ./ ManagedQueue.java

Author: robbie
Date: Sun Mar 22 21:24:00 2009
New Revision: 757258

URL: http://svn.apache.org/viewvc?rev=757258&view=rev
Log:
QPID-1767: add units to message age attribute description
Merged from branches/0.5-release : r757257

Modified:
    qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/   (props changed)
    qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java

Propchange: qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/
------------------------------------------------------------------------------
--- svn:mergeinfo (added)
+++ svn:mergeinfo Sun Mar 22 21:24:00 2009
@@ -0,0 +1 @@
+/qpid/branches/0.5-release/qpid/java/broker/src/main/java/org/apache/qpid/server/queue:757257

Modified: qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java
URL: http://svn.apache.org/viewvc/qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java?rev=757258&r1=757257&r2=757258&view=diff
==============================================================================
--- qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java (original)
+++ qpid/trunk/qpid/java/broker/src/main/java/org/apache/qpid/server/queue/ManagedQueue.java Sun Mar 22 21:24:00 2009
@@ -116,18 +116,18 @@
     boolean isAutoDelete() throws IOException;
 
     /**
      * Returns the maximum age of a message (expiration time)
      * @return the maximum age
      * @throws IOException
      */
     Long getMaximumMessageAge() throws IOException;
 
     /**
      * Sets the maximum age of a message
      * @param age  maximum age of message.
      * @throws IOException
      */
-    @MBeanAttribute(name="MaximumMessageAge", description="Threshold high value for message age on the broker")
+    @MBeanAttribute(name="MaximumMessageAge", description="Threshold high value(milliseconds) for message age")
     void setMaximumMessageAge(Long age) throws IOException;
 
     /**



---------------------------------------------------------------------
@@ -116,18 +116,18 @@
 
     /**
-     * Returns the maximum age of a message (expiration time)
+     * Returns the maximum age of a message (expiration time) in milliseconds
      * @return the maximum age
      * @throws IOException
@@ -116,18 +116,18 @@
 
     /**
-     * Sets the maximum age of a message
+     * Sets the maximum age of a message in milliseconds
      * @param age  maximum age of message.
      * @throws IOException
Apache Qpid - AMQP Messaging Implementation
Project:      http://qpid.apache.org
Use/Interact: mailto:commits-subscribe@qpid.apache.org